@@ -16,7 +16,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
-
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -26,6 +26,7 @@
 #define __GTK_SOURCE_UNDO_MANAGER_H__
 
 #include <gtk/gtk.h>
+#include <gtksourceview/gtksourcetypes.h>
 
 G_BEGIN_DECLS
 
@@ -34,7 +35,6 @@ G_BEGIN_DECLS
 #define GTK_SOURCE_IS_UNDO_MANAGER(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_SOURCE_TYPE_UNDO_MANAGER))
 #define GTK_SOURCE_UNDO_MANAGER_GET_INTERFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GTK_SOURCE_TYPE_UNDO_MANAGER, GtkSourceUndoManagerIface))
 
-typedef struct _GtkSourceUndoManager        	GtkSourceUndoManager;
 typedef struct _GtkSourceUndoManagerIface      	GtkSourceUndoManagerIface;
 
 struct _GtkSourceUndoManagerIface
@@ -73,5 +73,3 @@ void      gtk_source_undo_manager_can_redo_changed          (GtkSourceUndoManage
 G_END_DECLS
 
 #endif /* __GTK_SOURCE_UNDO_MANAGER_H__ */
-
-
